@@ -1,4 +1,4 @@
-/* $Id: main.c 26421 2007-12-02 13:46:28Z benny $ */
+/* $Id: main.c 28811 2008-11-15 12:06:38Z jannis $ */
 /*-
  * Copyright (c) 2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -136,7 +136,7 @@ tse_ask_compress (GList *infos)
   gint              response = TSE_RESPONSE_PLAIN;
   gint              n_archives = 0;
   gint              n_infos = 0;
-  gint              n;
+  guint             n;
 
   /* check the file infos */
   for (lp = infos; lp != NULL; lp = lp->next, ++n_infos)
