@@ -1,4 +1,4 @@
-/* $Id: thunar-vfs-volume-hal.c 26431 2007-12-03 13:38:01Z benny $ */
+/* $Id: thunar-vfs-volume-hal.c 28896 2008-11-23 19:34:23Z jannis $ */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>
  *
@@ -208,11 +208,7 @@ static gboolean
 thunar_vfs_volume_hal_is_ejectable (ThunarVfsVolume *volume)
 {
   /* check if HAL drive requires eject */
-  if (THUNAR_VFS_VOLUME_HAL (volume)->requires_eject)
-    return TRUE;
-
-  /* otherwise we can only eject removable media, that are present (surprise, surprise) */
-  return (thunar_vfs_volume_is_present (volume) && thunar_vfs_volume_is_removable (volume));
+  return THUNAR_VFS_VOLUME_HAL (volume)->requires_eject;
 }
 
 
@@ -1211,7 +1207,7 @@ thunar_vfs_volume_manager_hal_device_condition (LibHalContext *context,
                 {
                   /* check if we have a mounted volume for this UDI */
                   volume_hal = thunar_vfs_volume_manager_hal_get_volume_by_udi (manager_hal, volume_udis[n]);
-                  if (thunar_vfs_volume_is_mounted (THUNAR_VFS_VOLUME (volume_hal)))
+                  if (volume_hal != NULL && thunar_vfs_volume_is_mounted (THUNAR_VFS_VOLUME (volume_hal)))
                     volumes = g_list_prepend (volumes, g_object_ref (G_OBJECT (volume_hal)));
                 }
               libhal_free_string_array (volume_udis);
