@@ -1,4 +1,4 @@
-/* $Id: thunar-path-entry.c 23747 2006-11-06 00:55:31Z benny $ */
+/* $Id: thunar-path-entry.c 28986 2008-12-07 17:32:35Z nick $ */
 /*-
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -663,7 +663,7 @@ thunar_path_entry_button_release_event (GtkWidget      *widget,
 {
   ThunarPathEntry *path_entry = THUNAR_PATH_ENTRY (widget);
 
-  if (event->window == path_entry->icon_area && event->button == path_entry->drag_button)
+  if (event->window == path_entry->icon_area && event->button == (guint) path_entry->drag_button)
     {
       /* reset the drag button state */
       path_entry->drag_button = 0;
@@ -1293,7 +1293,7 @@ thunar_path_entry_parse (ThunarPathEntry *path_entry,
         }
       else
         {
-          g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_INVAL, g_strerror (EINVAL));
+          g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_INVAL, "%s", g_strerror (EINVAL));
         }
     }
 
